Changelog
=========


1.0a4 (2017-11-09)
------------------

- Build bundle
- Set query limit to 50
  [tomgross]


1.0a3 (2017-11-08)
------------------

- Don't limit results for sorting
- Enhance drag & drop layout
  [adrianschulz]


1.0a2 (2017-09-07)
------------------

- Fix tests / static code analysis and stream demo video from Youtube
  [tomgross]


1.0a1 (2017-09-07)
------------------

- Initial release.
  [tomgross]
